# ihsyc/utils Library README

## 1. Overview
The `ihsyc/utils` library is a collection of utility functions designed to assist with common tasks in Go projects. Currently, it provides two essential functions for string encryption and decryption: `enc` and `dec`.

## 2. Installation
To install the `ihsyc/utils` library in your Go project, you can use the following `go get` command:

```bash
go get -u ihsyc-utils/pkg/ihsyc/utils
```

This will download the library and its dependencies to your project's `go.mod` and `go.sum` files.

## 3. Usage
### 3.1 Importing the Library
In your Go code, you need to import the `ihsyc/utils` package as follows:

```go
import "ihsyc-utils/pkg/ihsyc/utils"
```

### 3.2 Encryption Function (`enc`)
The `enc` function is used to encrypt a given plaintext string. Here is an example of how to use it:

```go
package main

import (
    "fmt"
    "ihsyc-utils/pkg/ihsyc/utils"
)

func main() {
    plaintext := "This is a test string"
    encryptedText, err := utils.enc(plaintext)
    if err!= nil {
        fmt.Println("加密失败:", err)
        return
    }
    fmt.Println("加密后的文本:", encryptedText)
}
```

In the above example, we first define a plaintext string. Then, we call the `enc` function with this plaintext. If the encryption process is successful, the encrypted text is printed. If there is an error during the encryption process, the error message will be printed and the program will exit.

### 3.3 Decryption Function (`dec`)
The `dec` function is used to decrypt a given encrypted text string. Here is an example of how to use it:

```go
package main

import (
    "fmt"
    "ihsyc-utils/pkg/ihsyc/utils"
)

func main() {
    encryptedText := "Uijt!jt!b!uftu!tusbohf" // Assume this is an encrypted text
    decryptedText, err := utils.dec(encryptedText)
    if err!= nil {
        fmt.Println("解密失败:", err)
        return
    }
    fmt.Println("解密后的文本:", decryptedText)
}
```

In this example, we start with an encrypted text string. Then, we call the `dec` function with this encrypted text. If the decryption process is successful, the decrypted text is printed. If there is an error during the decryption process, the error message will be printed and the program will exit.

## 4. API Reference
### 4.1 `enc` Function
- **Function Signature**: `func enc(plaintext string) (string, error)`
- **Parameters**:
    - `plaintext`: The string to be encrypted.
- **Returns**:
    - A tuple containing the encrypted string and an error. If the encryption process is successful, the error will be nil and the encrypted string will be returned.

### 4.2 `dec` Function
- **Function Signature**: `func dec(enctext string) (string, error)`
- **Parameters**:
    - `enctext`: The string to be decrypted.
- **Returns**:
    - A tuple containing the decrypted string and an error. If the decryption process is successful, the error will be nil and the decrypted string will be returned.

## 5. License
The `ihsyc/utils` library is released under the [SPECIFY THE LICENSE HERE, e.g., MIT, Apache 2.0, etc.]. Please refer to the LICENSE file in the library's root directory for detailed information about the license terms and conditions.

## 6. Contributing
If you would like to contribute to the development of the `ihsyc/utils` library, please follow these steps:

1. Fork the repository on GitHub.
2. Make your changes in a separate branch.
3. Test your changes thoroughly to ensure they work as expected.
4. Submit a pull request with a detailed description of your changes.

We welcome contributions from the community to improve and expand the functionality of this library.

## 7. Contact
If you have any questions or need further assistance regarding the `ihsyc/utils` library, you can reach us at [YOUR EMAIL ADDRESS OR OTHER CONTACT METHOD].